@@ -16,6 +16,7 @@
 import io
 import logging
 import os
+import sys
 
 from osc_lib import utils
 import six
@@ -376,12 +377,17 @@ class APIv1(api.BaseAPI):
             stream=True,
         )
         if response.status_code == 200:
-            if not os.path.exists(os.path.dirname(file)):
-                if len(os.path.dirname(file)) > 0:
-                    os.makedirs(os.path.dirname(file))
-            with open(file, 'wb') as f:
-                for chunk in response.iter_content():
-                    f.write(chunk)
+            if file == '-':
+                with os.fdopen(sys.stdout.fileno(), 'wb') as f:
+                    for chunk in response.iter_content(64 * 1024):
+                        f.write(chunk)
+            else:
+                if not os.path.exists(os.path.dirname(file)):
+                    if len(os.path.dirname(file)) > 0:
+                        os.makedirs(os.path.dirname(file))
+                with open(file, 'wb') as f:
+                    for chunk in response.iter_content(64 * 1024):
+                        f.write(chunk)
 
     def object_set(
         self,
