@@ -539,6 +539,12 @@ class CreateServer(command.ShowOne):
             metavar='<user-data>',
             help=_('User data file to serve from the metadata server'),
         )
+        parser.add_argument(
+            '--description',
+            metavar='<description>',
+            help=_('Set description for the server (supported by '
+                   '--os-compute-api-version 2.19 or above)'),
+        )
         parser.add_argument(
             '--availability-zone',
             metavar='<zone-name>',
@@ -749,6 +755,12 @@ class CreateServer(command.ShowOne):
                            "exception": e}
                 )
 
+        if parsed_args.description:
+            if compute_client.api_version < api_versions.APIVersion("2.19"):
+                msg = _("Description is not supported for "
+                        "--os-compute-api-version less than 2.19")
+                raise exceptions.CommandError(msg)
+
         block_device_mapping_v2 = []
         if volume:
             block_device_mapping_v2 = [{'uuid': volume,
@@ -909,6 +921,9 @@ class CreateServer(command.ShowOne):
             scheduler_hints=hints,
             config_drive=config_drive)
 
+        if parsed_args.description:
+            boot_kwargs['description'] = parsed_args.description
+
         LOG.debug('boot_args: %s', boot_args)
         LOG.debug('boot_kwargs: %s', boot_kwargs)
 
@@ -947,6 +962,8 @@ class CreateServerDump(command.Command):
     It will create a dump file in the server(s) dumping the server(s)'
     memory, and also crash the server(s). OSC sees the dump file
     (server dump) as a kind of resource.
+
+    This command requires ``--os-compute-api-version`` 2.17 or greater.
     """
 
     def get_parser(self, prog_name):
@@ -1126,13 +1143,22 @@ class ListServer(command.Lister):
             default=False,
             help=_('Only display deleted servers (Admin only).')
         )
+        parser.add_argument(
+            '--changes-before',
+            metavar='<changes-before>',
+            default=None,
+            help=_("List only servers changed before a certain point of time. "
+                   "The provided time should be an ISO 8061 formatted time "
+                   "(e.g., 2016-03-05T06:27:59Z). "
+                   "(Supported by API versions '2.66' - '2.latest')")
+        )
         parser.add_argument(
             '--changes-since',
             metavar='<changes-since>',
             default=None,
             help=_("List only servers changed after a certain point of time."
-                   " The provided time should be an ISO 8061 formatted time."
-                   " ex 2016-03-04T06:27:59Z .")
+                   " The provided time should be an ISO 8061 formatted time"
+                   " (e.g., 2016-03-04T06:27:59Z).")
         )
         return parser
 
@@ -1186,10 +1212,24 @@ class ListServer(command.Lister):
             'all_tenants': parsed_args.all_projects,
             'user_id': user_id,
             'deleted': parsed_args.deleted,
+            'changes-before': parsed_args.changes_before,
             'changes-since': parsed_args.changes_since,
         }
         LOG.debug('search options: %s', search_opts)
 
+        if search_opts['changes-before']:
+            if compute_client.api_version < api_versions.APIVersion('2.66'):
+                msg = _('--os-compute-api-version 2.66 or later is required')
+                raise exceptions.CommandError(msg)
+
+            try:
+                timeutils.parse_isotime(search_opts['changes-before'])
+            except ValueError:
+                raise exceptions.CommandError(
+                    _('Invalid changes-before value: %s') %
+                    search_opts['changes-before']
+                )
+
         if search_opts['changes-since']:
             try:
                 timeutils.parse_isotime(search_opts['changes-since'])
@@ -1405,9 +1445,38 @@ class MigrateServer(command.Command):
             help=_('Server (name or ID)'),
         )
         parser.add_argument(
+            '--live-migration',
+            dest='live_migration',
+            action='store_true',
+            help=_('Live migrate the server. Use the ``--host`` option to '
+                   'specify a target host for the migration which will be '
+                   'validated by the scheduler.'),
+        )
+        # The --live and --host options are mutually exclusive ways of asking
+        # for a target host during a live migration.
+        host_group = parser.add_mutually_exclusive_group()
+        # TODO(mriedem): Remove --live in the next major version bump after
+        #  the Train release.
+        host_group.add_argument(
             '--live',
             metavar='<hostname>',
-            help=_('Target hostname'),
+            help=_('**Deprecated** This option is problematic in that it '
+                   'requires a host and prior to compute API version 2.30, '
+                   'specifying a host during live migration will bypass '
+                   'validation by the scheduler which could result in '
+                   'failures to actually migrate the server to the specified '
+                   'host or over-subscribe the host. Use the '
+                   '``--live-migration`` option instead. If both this option '
+                   'and ``--live-migration`` are used, ``--live-migration`` '
+                   'takes priority.'),
+        )
+        # TODO(mriedem): Add support for --os-compute-api-version >= 2.56 where
+        # you can cold migrate to a specified target host.
+        host_group.add_argument(
+            '--host',
+            metavar='<hostname>',
+            help=_('Live migrate the server to the specified host. Requires '
+                   '``--os-compute-api-version`` 2.30 or greater.'),
         )
         migration_group = parser.add_mutually_exclusive_group()
         migration_group.add_argument(
@@ -1445,6 +1514,15 @@ class MigrateServer(command.Command):
         )
         return parser
 
+    def _log_warning_for_live(self, parsed_args):
+        if parsed_args.live:
+            # NOTE(mriedem): The --live option requires a host and if
+            # --os-compute-api-version is less than 2.30 it will forcefully
+            # bypass the scheduler which is dangerous.
+            self.log.warning(_(
+                'The --live option has been deprecated. Please use the '
+                '--live-migration option instead.'))
+
     def take_action(self, parsed_args):
 
         def _show_progress(progress):
@@ -1458,19 +1536,45 @@ class MigrateServer(command.Command):
             compute_client.servers,
             parsed_args.server,
         )
-        if parsed_args.live:
+        # Check for live migration.
+        if parsed_args.live or parsed_args.live_migration:
+            # Always log a warning if --live is used.
+            self._log_warning_for_live(parsed_args)
             kwargs = {
-                'host': parsed_args.live,
                 'block_migration': parsed_args.block_migration
             }
+            # Prefer --live-migration over --live if both are specified.
+            if parsed_args.live_migration:
+                # Technically we could pass a non-None host with
+                # --os-compute-api-version < 2.30 but that is the same thing
+                # as the --live option bypassing the scheduler which we don't
+                # want to support, so if the user is using --live-migration
+                # and --host, we want to enforce that they are using version
+                # 2.30 or greater.
+                if (parsed_args.host and
+                        compute_client.api_version <
+                        api_versions.APIVersion('2.30')):
+                    raise exceptions.CommandError(
+                        '--os-compute-api-version 2.30 or greater is required '
+                        'when using --host')
+                # The host parameter is required in the API even if None.
+                kwargs['host'] = parsed_args.host
+            else:
+                kwargs['host'] = parsed_args.live
+
             if compute_client.api_version < api_versions.APIVersion('2.25'):
                 kwargs['disk_over_commit'] = parsed_args.disk_overcommit
             server.live_migrate(**kwargs)
         else:
-            if parsed_args.block_migration or parsed_args.disk_overcommit:
-                raise exceptions.CommandError("--live must be specified if "
-                                              "--block-migration or "
-                                              "--disk-overcommit is specified")
+            if (parsed_args.block_migration or parsed_args.disk_overcommit or
+                    parsed_args.host):
+                # TODO(mriedem): Allow --host for cold migration if
+                # --os-compute-api-version >= 2.56.
+                raise exceptions.CommandError(
+                    "--live-migration must be specified if "
+                    "--block-migration, --disk-overcommit or --host is "
+                    "specified")
+
             server.migrate()
 
         if parsed_args.wait:
@@ -1598,6 +1702,12 @@ class RebuildServer(command.ShowOne):
             help=_('Set a property on the rebuilt instance '
                    '(repeat option to set multiple values)'),
         )
+        parser.add_argument(
+            '--description',
+            metavar='<description>',
+            help=_('New description for the server (supported by '
+                   '--os-compute-api-version 2.19 or above'),
+        )
         parser.add_argument(
             '--wait',
             action='store_true',
@@ -1642,6 +1752,12 @@ class RebuildServer(command.ShowOne):
         kwargs = {}
         if parsed_args.property:
             kwargs['meta'] = parsed_args.property
+        if parsed_args.description:
+            if server.api_version < api_versions.APIVersion("2.19"):
+                msg = _("Description is not supported for "
+                        "--os-compute-api-version less than 2.19")
+                raise exceptions.CommandError(msg)
+            kwargs['description'] = parsed_args.description
 
         if parsed_args.key_name or parsed_args.key_unset:
             if compute_client.api_version < api_versions.APIVersion('2.54'):
@@ -2063,6 +2179,12 @@ class SetServer(command.Command):
             choices=['active', 'error'],
             help=_('New server state (valid value: active, error)'),
         )
+        parser.add_argument(
+            '--description',
+            metavar='<description>',
+            help=_('New server description (supported by '
+                   '--os-compute-api-version 2.19 or above)'),
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -2094,6 +2216,13 @@ class SetServer(command.Command):
                 msg = _("Passwords do not match, password unchanged")
                 raise exceptions.CommandError(msg)
 
+        if parsed_args.description:
+            if server.api_version < api_versions.APIVersion("2.19"):
+                msg = _("Description is not supported for "
+                        "--os-compute-api-version less than 2.19")
+                raise exceptions.CommandError(msg)
+            server.update(description=parsed_args.description)
+
 
 class ShelveServer(command.Command):
     _description = _("Shelve server(s)")
@@ -2453,6 +2582,13 @@ class UnsetServer(command.Command):
             help=_('Property key to remove from server '
                    '(repeat option to remove multiple values)'),
         )
+        parser.add_argument(
+            '--description',
+            dest='description',
+            action='store_true',
+            help=_('Unset server description (supported by '
+                   '--os-compute-api-version 2.19 or above)'),
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -2468,6 +2604,16 @@ class UnsetServer(command.Command):
                 parsed_args.property,
             )
 
+        if parsed_args.description:
+            if compute_client.api_version < api_versions.APIVersion("2.19"):
+                msg = _("Description is not supported for "
+                        "--os-compute-api-version less than 2.19")
+                raise exceptions.CommandError(msg)
+            compute_client.servers.update(
+                server,
+                description="",
+            )
+
 
 class UnshelveServer(command.Command):
     _description = _("Unshelve server(s)")
