@@ -20,6 +20,7 @@ import logging
 from keystoneauth1 import exceptions as ks_exc
 from osc_lib.cli import parseractions
 from osc_lib.command import command
+from osc_lib import exceptions
 from osc_lib import utils
 import six
 
@@ -117,12 +118,25 @@ class DeleteProject(command.Command):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
+        errors = 0
         for project in parsed_args.projects:
-            project_obj = utils.find_resource(
-                identity_client.tenants,
-                project,
-            )
-            identity_client.tenants.delete(project_obj.id)
+            try:
+                project_obj = utils.find_resource(
+                    identity_client.tenants,
+                    project,
+                )
+                identity_client.tenants.delete(project_obj.id)
+            except Exception as e:
+                errors += 1
+                LOG.error(_("Failed to delete project with "
+                          "name or ID '%(project)s': %(e)s"),
+                          {'project': project, 'e': e})
+
+        if errors > 0:
+            total = len(parsed_args.projects)
+            msg = (_("%(errors)s of %(total)s projects failed "
+                   "to delete.") % {'errors': errors, 'total': total})
+            raise exceptions.CommandError(msg)
 
 
 class ListProject(command.Lister):
@@ -136,6 +150,13 @@ class ListProject(command.Lister):
             default=False,
             help=_('List additional fields in output'),
         )
+        parser.add_argument(
+            '--sort',
+            metavar='<key>[:<direction>]',
+            help=_('Sort output by selected keys and directions (asc or desc) '
+                   '(default: asc), repeat this option to specify multiple '
+                   'keys and directions.'),
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -144,6 +165,8 @@ class ListProject(command.Lister):
         else:
             columns = ('ID', 'Name')
         data = self.app.client_manager.identity.tenants.list()
+        if parsed_args.sort:
+            data = utils.sort_items(data, parsed_args.sort)
         return (columns,
                 (utils.get_item_properties(
                     s, columns,
@@ -266,7 +289,7 @@ class ShowProject(command.ShowOne):
         # the API has and handle the extra top level properties.
         reserved = ('name', 'id', 'enabled', 'description')
         properties = {}
-        for k, v in info.items():
+        for k, v in list(info.items()):
             if k not in reserved:
                 # If a key is not in `reserved` it's a property, pop it
                 info.pop(k)
