@@ -21,20 +21,20 @@ import logging
 import os
 import sys
 
-if os.name == "nt":
-    import msvcrt
-else:
-    msvcrt = None
-
 from glanceclient.common import utils as gc_utils
+from osc_lib.api import utils as api_utils
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import utils
 import six
 
-from openstackclient.api import utils as api_utils
 from openstackclient.i18n import _
 
+if os.name == "nt":
+    import msvcrt
+else:
+    msvcrt = None
+
 
 CONTAINER_CHOICES = ["ami", "ari", "aki", "bare", "docker", "ova", "ovf"]
 DEFAULT_CONTAINER_FORMAT = 'bare'
@@ -625,11 +625,11 @@ class SetImage(command.Command):
         kwargs = {}
         copy_attrs = ('name', 'owner', 'min_disk', 'min_ram', 'properties',
                       'container_format', 'disk_format', 'size', 'store',
-                      'location', 'copy_from', 'volume', 'force', 'checksum')
+                      'location', 'copy_from', 'volume', 'checksum')
         for attr in copy_attrs:
             if attr in parsed_args:
                 val = getattr(parsed_args, attr, None)
-                if val:
+                if val is not None:
                     # Only include a value in kwargs for attributes that are
                     # actually present on the command line
                     kwargs[attr] = val
@@ -653,6 +653,8 @@ class SetImage(command.Command):
             kwargs['is_public'] = True
         if parsed_args.private:
             kwargs['is_public'] = False
+        if parsed_args.force:
+            kwargs['force'] = True
 
         # Wrap the call to catch exceptions in order to close files
         try:
@@ -713,6 +715,12 @@ class ShowImage(command.ShowOne):
 
     def get_parser(self, prog_name):
         parser = super(ShowImage, self).get_parser(prog_name)
+        parser.add_argument(
+            "--human-readable",
+            default=False,
+            action='store_true',
+            help=_("Print image size in a human-friendly format."),
+        )
         parser.add_argument(
             "image",
             metavar="<image>",
@@ -729,5 +737,8 @@ class ShowImage(command.ShowOne):
 
         info = {}
         info.update(image._info)
+        if parsed_args.human_readable:
+            if 'size' in info:
+                info['size'] = utils.format_size(info['size'])
         info['properties'] = utils.format_dict(info.get('properties', {}))
         return zip(*sorted(six.iteritems(info)))
