@@ -21,13 +21,13 @@ import logging
 
 from glanceclient.common import utils as gc_utils
 from openstack.image import image_signer
+from osc_lib.api import utils as api_utils
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 import six
 
-from openstackclient.api import utils as api_utils
 from openstackclient.i18n import _
 from openstackclient.identity import common
 
@@ -643,6 +643,9 @@ class ListImage(command.Lister):
 
         # List of image data received
         data = []
+        limit = None
+        if 'limit' in kwargs:
+            limit = kwargs['limit']
         if 'marker' in kwargs:
             data = image_client.api.image_list(**kwargs)
         else:
@@ -655,6 +658,8 @@ class ListImage(command.Lister):
                 data.extend(page)
                 # Set the marker to the id of the last item we received
                 marker = page[-1]['id']
+                if limit:
+                    break
 
         if parsed_args.property:
             for attr, value in parsed_args.property.items():
