@@ -48,6 +48,10 @@ def _get_attrs(client_manager, parsed_args):
         object_id = network_client.find_qos_policy(
             parsed_args.rbac_object,
             ignore_missing=False).id
+    if parsed_args.type == 'security_group':
+        object_id = network_client.find_security_group(
+            parsed_args.rbac_object,
+            ignore_missing=False).id
     attrs['object_id'] = object_id
 
     identity_client = client_manager.identity
@@ -87,9 +91,9 @@ class CreateNetworkRBAC(command.ShowOne):
             '--type',
             metavar="<type>",
             required=True,
-            choices=['qos_policy', 'network'],
+            choices=['security_group', 'qos_policy', 'network'],
             help=_('Type of the object that RBAC policy '
-                   'affects ("qos_policy" or "network")')
+                   'affects ("security_group", "qos_policy" or "network")')
         )
         parser.add_argument(
             '--action',
@@ -178,9 +182,10 @@ class ListNetworkRBAC(command.Lister):
         parser.add_argument(
             '--type',
             metavar='<type>',
-            choices=['qos_policy', 'network'],
+            choices=['security_group', 'qos_policy', 'network'],
             help=_('List network RBAC policies according to '
-                   'given object type ("qos_policy" or "network")')
+                   'given object type ("security_group", "qos_policy" '
+                   'or "network")')
         )
         parser.add_argument(
             '--action',
