@@ -73,6 +73,14 @@ def _convert_to_lowercase(string):
     return string.lower()
 
 
+def _convert_ipvx_case(string):
+    if string.lower() == 'ipv4':
+        return 'IPv4'
+    if string.lower() == 'ipv6':
+        return 'IPv6'
+    return string
+
+
 def _is_icmp_protocol(protocol):
     # NOTE(rtheis): Neutron has deprecated protocol icmpv6.
     # However, while the OSC CLI doesn't document the protocol,
@@ -159,8 +167,8 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             help=_("IP protocol (ah, dccp, egp, esp, gre, icmp, igmp, "
                    "ipv6-encap, ipv6-frag, ipv6-icmp, ipv6-nonxt, "
                    "ipv6-opts, ipv6-route, ospf, pgm, rsvp, sctp, tcp, "
-                   "udp, udplite, vrrp and integer representations [0-255]; "
-                   "default: tcp)")
+                   "udp, udplite, vrrp and integer representations [0-255] "
+                   "or any; default: tcp)")
         )
         protocol_group.add_argument(
             '--proto',
@@ -183,6 +191,7 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             '--ethertype',
             metavar='<ethertype>',
             choices=['IPv4', 'IPv6'],
+            type=_convert_ipvx_case,
             help=_("Ethertype of network traffic "
                    "(IPv4, IPv6; default: based on IP protocol)")
         )
@@ -230,6 +239,8 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             protocol = parsed_args.protocol
         if parsed_args.proto is not None:
             protocol = parsed_args.proto
+        if protocol == 'any':
+            protocol = None
         return protocol
 
     def _is_ipv6_protocol(self, protocol):
@@ -237,7 +248,7 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
         # However, while the OSC CLI doesn't document the protocol,
         # the code must still handle it. In addition, handle both
         # protocol names and numbers.
-        if (protocol.startswith('ipv6-') or
+        if (protocol is not None and protocol.startswith('ipv6-') or
                 protocol in ['icmpv6', '41', '43', '44', '58', '59', '60']):
             return True
         else:
@@ -294,9 +305,9 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
         if parsed_args.dst_port and not is_icmp_protocol:
             attrs['port_range_min'] = parsed_args.dst_port[0]
             attrs['port_range_max'] = parsed_args.dst_port[1]
-        if parsed_args.icmp_type:
+        if parsed_args.icmp_type is not None and parsed_args.icmp_type >= 0:
             attrs['port_range_min'] = parsed_args.icmp_type
-        if parsed_args.icmp_code:
+        if parsed_args.icmp_code is not None and parsed_args.icmp_code >= 0:
             attrs['port_range_max'] = parsed_args.icmp_code
 
         # NOTE(dtroyer): --src-ip and --src-group were deprecated in Nov 2016.
