@@ -16,7 +16,6 @@ import uuid
 
 from tempest.lib import exceptions
 
-from openstackclient.tests.functional import base
 from openstackclient.tests.functional.compute.v2 import common
 from openstackclient.tests.functional.volume.v2 import common as volume_common
 
@@ -27,7 +26,7 @@ class ServerTests(common.ComputeTestCase):
     @classmethod
     def setUpClass(cls):
         super(ServerTests, cls).setUpClass()
-        cls.haz_network = base.is_service_enabled('network')
+        cls.haz_network = cls.is_service_enabled('network')
 
     def test_server_list(self):
         """Test server list, set"""
@@ -64,6 +63,84 @@ class ServerTests(common.ComputeTestCase):
         self.assertNotIn(name1, col_name)
         self.assertIn(name2, col_name)
 
+    def test_server_list_with_changes_before(self):
+        """Test server list.
+
+        Getting the servers list with updated_at time equal or
+        before than changes-before.
+        """
+        cmd_output = self.server_create()
+        server_name1 = cmd_output['name']
+
+        cmd_output = self.server_create()
+        server_name2 = cmd_output['name']
+        updated_at2 = cmd_output['updated']
+
+        cmd_output = self.server_create()
+        server_name3 = cmd_output['name']
+
+        cmd_output = json.loads(self.openstack(
+            '--os-compute-api-version 2.66 ' +
+            'server list -f json '
+            '--changes-before ' + updated_at2
+        ))
+
+        col_updated = [server["Name"] for server in cmd_output]
+        self.assertIn(server_name1, col_updated)
+        self.assertIn(server_name2, col_updated)
+        self.assertNotIn(server_name3, col_updated)
+
+    def test_server_list_with_changes_since(self):
+        """Test server list.
+
+        Getting the servers list with updated_at time equal or
+        later than changes-since.
+        """
+        cmd_output = self.server_create()
+        server_name1 = cmd_output['name']
+        cmd_output = self.server_create()
+        server_name2 = cmd_output['name']
+        updated_at2 = cmd_output['updated']
+        cmd_output = self.server_create()
+        server_name3 = cmd_output['name']
+
+        cmd_output = json.loads(self.openstack(
+            'server list -f json '
+            '--changes-since ' + updated_at2
+        ))
+
+        col_updated = [server["Name"] for server in cmd_output]
+        self.assertNotIn(server_name1, col_updated)
+        self.assertIn(server_name2, col_updated)
+        self.assertIn(server_name3, col_updated)
+
+    def test_server_list_with_changes_before_and_changes_since(self):
+        """Test server list.
+
+        Getting the servers list with updated_at time equal or before than
+        changes-before and equal or later than changes-since.
+        """
+        cmd_output = self.server_create()
+        server_name1 = cmd_output['name']
+        cmd_output = self.server_create()
+        server_name2 = cmd_output['name']
+        updated_at2 = cmd_output['updated']
+        cmd_output = self.server_create()
+        server_name3 = cmd_output['name']
+        updated_at3 = cmd_output['updated']
+
+        cmd_output = json.loads(self.openstack(
+            '--os-compute-api-version 2.66 ' +
+            'server list -f json ' +
+            '--changes-since ' + updated_at2 +
+            ' --changes-before ' + updated_at3
+        ))
+
+        col_updated = [server["Name"] for server in cmd_output]
+        self.assertNotIn(server_name1, col_updated)
+        self.assertIn(server_name2, col_updated)
+        self.assertIn(server_name3, col_updated)
+
     def test_server_set(self):
         """Test server create, delete, set, show"""
         cmd_output = self.server_create()
@@ -618,7 +695,9 @@ class ServerTests(common.ComputeTestCase):
                 server_name
             )
         except exceptions.CommandFailed as e:
-            self.assertIn('nics are required after microversion 2.36',
-                          e.stderr)
-        else:
-            self.fail('CommandFailed should be raised.')
+            # If we got here, it shouldn't be because a nics value wasn't
+            # provided to the server; it is likely due to something else in
+            # the functional tests like there being multiple available
+            # networks and the test didn't specify a specific network.
+            self.assertNotIn('nics are required after microversion 2.36',
+                             e.stderr)
