@@ -14,8 +14,8 @@
 #
 
 import copy
-import mock
 
+import mock
 from osc_lib import exceptions
 from osc_lib import utils
 
@@ -116,7 +116,7 @@ class TestImageCreate(TestImage):
         self.images_mock.configure_mock(**mock_exception)
         arglist = [
             '--container-format', 'ovf',
-            '--disk-format', 'fs',
+            '--disk-format', 'ami',
             '--min-disk', '10',
             '--min-ram', '4',
             '--protected',
@@ -126,7 +126,7 @@ class TestImageCreate(TestImage):
         ]
         verifylist = [
             ('container_format', 'ovf'),
-            ('disk_format', 'fs'),
+            ('disk_format', 'ami'),
             ('min_disk', 10),
             ('min_ram', 4),
             ('protected', True),
@@ -147,7 +147,7 @@ class TestImageCreate(TestImage):
         self.images_mock.create.assert_called_with(
             name=self.new_image.name,
             container_format='ovf',
-            disk_format='fs',
+            disk_format='ami',
             min_disk=10,
             min_ram=4,
             protected=True,
@@ -417,7 +417,7 @@ class TestImageList(TestImage):
         ), )
         self.assertEqual(datalist, tuple(data))
 
-    @mock.patch('openstackclient.api.utils.simple_filter')
+    @mock.patch('osc_lib.api.utils.simple_filter')
     def test_image_list_property_option(self, sf_mock):
         sf_mock.side_effect = [
             [self.image_info], [],
@@ -689,10 +689,37 @@ class TestImageSet(TestImage):
         )
         self.assertIsNone(result)
 
+    def test_image_set_numeric_options_to_zero(self):
+        arglist = [
+            '--min-disk', '0',
+            '--min-ram', '0',
+            self._image.name,
+        ]
+        verifylist = [
+            ('min_disk', 0),
+            ('min_ram', 0),
+            ('image', self._image.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        kwargs = {
+            'min_disk': 0,
+            'min_ram': 0,
+        }
+        # ImageManager.update(image, **kwargs)
+        self.images_mock.update.assert_called_with(
+            self._image.id,
+            **kwargs
+        )
+        self.assertIsNone(result)
+
 
 class TestImageShow(TestImage):
 
-    _image = image_fakes.FakeImage.create_one_image()
+    _image = image_fakes.FakeImage.create_one_image(
+        attrs={'size': 2000})
     columns = (
         'container_format',
         'disk_format',
@@ -704,6 +731,7 @@ class TestImageShow(TestImage):
         'owner',
         'properties',
         'protected',
+        'size',
     )
     data = (
         _image.container_format,
@@ -716,6 +744,7 @@ class TestImageShow(TestImage):
         _image.owner,
         utils.format_dict(_image.properties),
         _image.protected,
+        _image.size,
     )
 
     def setUp(self):
@@ -745,3 +774,25 @@ class TestImageShow(TestImage):
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
+
+    def test_image_show_human_readable(self):
+        arglist = [
+            '--human-readable',
+            self._image.id,
+        ]
+        verifylist = [
+            ('human_readable', True),
+            ('image', self._image.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
+        columns, data = self.cmd.take_action(parsed_args)
+        self.images_mock.get.assert_called_with(
+            self._image.id,
+        )
+
+        size_index = columns.index('size')
+        self.assertEqual(data[size_index], '2K')
